@@ -4,6 +4,8 @@ from pyplanet.apps.contrib.live_rankings.views import LiveRankingsWidget
 from pyplanet.apps.core.trackmania import callbacks as tm_signals
 from pyplanet.apps.core.maniaplanet import callbacks as mp_signals
 
+from pyplanet.contrib.setting import Setting
+
 
 class LiveRankings(AppConfig):
 	game_dependencies = ['trackmania']
@@ -13,22 +15,45 @@ class LiveRankings(AppConfig):
 		super().__init__(*args, **kwargs)
 
 		self.current_rankings = []
+		self.points_repartition = []
+		self.current_finishes = []
 		self.widget = None
+		self.dedimania_enabled = False
+
+		self.setting_rankings_amount = Setting(
+			'rankings_amount', 'Amount of rankings to display', Setting.CAT_BEHAVIOUR, type=int,
+			description='Amount of live rankings to display (minimum: 15).',
+			default=15
+		)
+		self.setting_nadeo_live_ranking = Setting(
+			'nadeo_live_ranking', 'Show the Nadeo live rankings widget', Setting.CAT_BEHAVIOUR, type=bool,
+			description='Show the Nadeo live rankings widgets besides the live rankings widget.', default=True,
+			change_target=self.nadeo_widget_change
+		)
 
 	async def on_start(self):
+		# Init settings.
+		await self.context.setting.register(
+			self.setting_rankings_amount, self.setting_nadeo_live_ranking
+		)
+
 		# Register signals
 		self.context.signals.listen(mp_signals.map.map_start, self.map_start)
+		self.context.signals.listen(mp_signals.flow.round_start, self.round_start)
 		self.context.signals.listen(tm_signals.finish, self.player_finish)
 		self.context.signals.listen(tm_signals.waypoint, self.player_waypoint)
 		self.context.signals.listen(mp_signals.player.player_connect, self.player_connect)
 		self.context.signals.listen(tm_signals.give_up, self.player_giveup)
 		self.context.signals.listen(tm_signals.scores, self.scores)
 
-		# Make sure we move the rounds_scores and other gui elements.
-		self.instance.ui_manager.properties.set_attribute('round_scores', 'pos', '-126.5 87. 150.')
+		# Make sure we move the multilap_info and disable the checkpoint_ranking and round_scores elements.
 		self.instance.ui_manager.properties.set_visibility('checkpoint_ranking', False)
+		self.instance.ui_manager.properties.set_visibility('round_scores', await self.setting_nadeo_live_ranking.get_value())
+		self.instance.ui_manager.properties.set_attribute('round_scores', 'pos', '-126.5 80. 150.')
 		self.instance.ui_manager.properties.set_attribute('multilap_info', 'pos', '107., 88., 5.')
 
+		self.dedimania_enabled = ('dedimania' in self.instance.apps.apps and 'dedimania' not in self.instance.apps.unloaded_apps)
+
 		self.widget = LiveRankingsWidget(self)
 		await self.widget.display()
 
@@ -42,17 +67,29 @@ class LiveRankings(AppConfig):
 			await self.handle_scores(scores['players'])
 			await self.widget.display()
 
+		await self.get_points_repartition()
+
+	async def nadeo_widget_change(self, *args, **kwargs):
+		self.instance.ui_manager.properties.set_visibility('round_scores', await self.setting_nadeo_live_ranking.get_value())
+		await self.instance.ui_manager.properties.send_properties()
+
 	def is_mode_supported(self, mode):
 		mode = mode.lower()
 		return mode.startswith('timeattack') or mode.startswith('rounds') or mode.startswith('team') or \
 			   mode.startswith('laps') or mode.startswith('cup')
 
 	async def scores(self, section, players, **kwargs):
+		if section == 'PreEndRound':
+			# Do not update the live rankings on the 'pre end round'-stage.
+			# This will make the points added disappear without updating the actual scores.
+			return
+
 		await self.handle_scores(players)
 		await self.widget.display()
 
 	async def handle_scores(self, players):
 		self.current_rankings = []
+		self.current_finishes = []
 
 		current_script = (await self.instance.mode_manager.get_current_script()).lower()
 		if 'timeattack' in current_script:
@@ -71,11 +108,11 @@ class LiveRankings(AppConfig):
 			for player in players:
 				if 'map_points' in player:
 					if player['map_points'] != -1:
-						new_ranking = dict(login=player['player'].login, nickname=player['player'].nickname, score=player['map_points'])
+						new_ranking = dict(login=player['player'].login, nickname=player['player'].nickname, score=player['map_points'], points_added=0)
 						self.current_rankings.append(new_ranking)
 				elif 'mappoints' in player:
 					if player['mappoints'] != -1:
-						new_ranking = dict(login=player['login'], nickname=player['name'], score=player['mappoints'])
+						new_ranking = dict(login=player['login'], nickname=player['name'], score=player['mappoints'], points_added=0)
 						self.current_rankings.append(new_ranking)
 
 			self.current_rankings.sort(key=lambda x: x['score'])
@@ -83,8 +120,14 @@ class LiveRankings(AppConfig):
 
 	async def map_start(self, map, restarted, **kwargs):
 		self.current_rankings = []
+		self.current_finishes = []
+		self.dedimania_enabled = ('dedimania' in self.instance.apps.apps and 'dedimania' not in self.instance.apps.unloaded_apps)
+		await self.get_points_repartition()
 		await self.widget.display()
 
+	async def round_start(self, count, time):
+		await self.get_points_repartition()
+
 	async def player_connect(self, player, is_spectator, source, signal):
 		await self.widget.display(player=player)
 
@@ -128,20 +171,50 @@ class LiveRankings(AppConfig):
 			await self.player_waypoint(player, race_time, flow, raw)
 			return
 
-		if 'timeattack' not in current_script:
-			return
+		if 'timeattack' in current_script:
+			current_rankings = [x for x in self.current_rankings if x['login'] == player.login]
+			score = lap_time
+			if len(current_rankings) > 0:
+				current_ranking = current_rankings[0]
 
-		current_rankings = [x for x in self.current_rankings if x['login'] == player.login]
-		score = lap_time
-		if len(current_rankings) > 0:
-			current_ranking = current_rankings[0]
-
-			if score < current_ranking['score']:
-				current_ranking['score'] = score
+				if score < current_ranking['score']:
+					current_ranking['score'] = score
+					self.current_rankings.sort(key=lambda x: x['score'])
+					await self.widget.display()
+			else:
+				new_ranking = dict(login=player.login, nickname=player.nickname, score=score)
+				self.current_rankings.append(new_ranking)
 				self.current_rankings.sort(key=lambda x: x['score'])
 				await self.widget.display()
-		else:
-			new_ranking = dict(login=player.login, nickname=player.nickname, score=score)
-			self.current_rankings.append(new_ranking)
-			self.current_rankings.sort(key=lambda x: x['score'])
+
+			return
+
+		if 'rounds' in current_script or 'team' in current_script or 'cup' in current_script:
+			new_finish = dict(login=player.login, nickname=player.nickname, score=race_time)
+			self.current_finishes.append(new_finish)
+
+			new_finish_rank = len(self.current_finishes) - 1
+			new_finish['points_added'] = self.points_repartition[new_finish_rank] \
+				if len(self.points_repartition) > new_finish_rank \
+				else self.points_repartition[(len(self.points_repartition) - 1)]
+
+			current_ranking = next((item for item in self.current_rankings if item['login'] == player.login), None)
+			if current_ranking is not None:
+				current_ranking['points_added'] = new_finish['points_added']
+			else:
+				new_finish['score'] = 0
+				self.current_rankings.append(new_finish)
+
+			self.current_rankings.sort(key=lambda x: (-x['score'], -x['points_added']))
 			await self.widget.display()
+			return
+
+	async def get_points_repartition(self):
+		current_script = (await self.instance.mode_manager.get_current_script()).lower()
+		if 'rounds' in current_script or 'team' in current_script or 'cup' in current_script:
+			points_repartition = await self.instance.gbx('Trackmania.GetPointsRepartition')
+			self.points_repartition = points_repartition['pointsrepartition']
+		else:
+			# Reset the points repartition array.
+			self.points_repartition = []
+			self.current_finishes = []
