@@ -180,7 +180,7 @@ class MxSearchListView(ManualListView):
 			self.cache = [dict(
 				mxid=_map['TrackID'],
 				name=_map['Name'],
-				gbxname=_map['GbxMapName'],
+				gbxname=_map['GbxMapName'] if _map['GbxMapName'] != '?' else _map['Name'],
 				author=_map['Username'],
 				envir=_map['EnvironmentName'],
 				awards='$fff🏆 {}'.format(_map['AwardCount']) if _map['AwardCount'] > 0 else "",
@@ -193,7 +193,7 @@ class MxSearchListView(ManualListView):
 			self.cache = [dict(
 				mxid=_map['TrackID'],
 				name=_map['Name'],
-				gbxname=_map['GbxMapName'],
+				gbxname=_map['GbxMapName'] if _map['GbxMapName'] != '?' else _map['Name'],
 				author=_map['Username'],
 				envir=_map['EnvironmentName'],
 				awards='$fff🏆 {}'.format(_map['AwardCount']) if _map['AwardCount'] > 0 else "",
@@ -451,13 +451,28 @@ class MxStatusListView(ManualListView):
 			if cancel is True:
 				return
 
+			folders = None
+			if 'jukebox' in self.app.instance.apps.apps:
+				# Check if the map was part of a map folder.
+				# Remove the current version and add the new version to the folders.
+				folders = await self.app.instance.apps.apps['jukebox'].folder_manager.get_folders_containing_map(instance['map_id'])
+				if folders is not None and len(folders) != 0:
+					for folder in folders:
+						await self.app.instance.apps.apps['jukebox'].folder_manager.remove_map_from_folder(folder.id, instance['map_id'])
+
 			# Remove the current version from the server.
 			mock_remove = namedtuple("data", ["nr"])
 			await self.app.instance.apps.apps['admin'].map.remove_map(player, mock_remove(nr=instance['map_id']))
 
 			# Add the new version from MX.
 			mock_add = namedtuple("data", ["maps"])
-			await self.app.add_mx_map(player, mock_add(maps=[instance['index']]))
+			added_map = await self.app.add_mx_map(player, mock_add(maps=[instance['index']]))
+
+			# If the map could be added and was part of folders, update the folders to contain the new version.
+			if added_map is not None and len(added_map) == 1:
+				if folders is not None and len(folders) != 0:
+					for folder in folders:
+						await self.app.instance.apps.apps['jukebox'].folder_manager.add_map_to_folder(folder.id, added_map[0].id)
 
 			# Update the current view.
 			await self.refresh(player=player)
@@ -491,8 +506,9 @@ class MxStatusListView(ManualListView):
 				if '.' in mx_map[1]['UpdatedAt']:
 					date_format = '%Y-%m-%dT%H:%M:%S.%f'
 				mx_version_date = datetime.strptime(mx_map[1]['UpdatedAt'], date_format).strftime("%Y-%m-%d %H:%M:%S")
+				mx_map_uid = mx_map[1]['TrackUID'] if 'TrackUID' in mx_map[1] else mx_map[1]['MapUID']
 
-				if mx_map[1]['TrackUID'] == item.uid:
+				if mx_map_uid == item.uid:
 					version_match = '$0a0Up-to-date'
 					version_match_order = 2
 				else:
